"""Constants for speaker recognition service."""

ENV_HOST = "HOST"
ENV_PORT = "PORT"
ENV_LOG_LEVEL = "LOG_LEVEL"
ENV_ACCESS_LOG = "ACCESS_LOG"
ENV_EMBEDDINGS_DIR = "EMBEDDINGS_DIR"

DEFAULT_HOST = "0.0.0.0"
DEFAULT_PORT = 8099
DEFAULT_LOG_LEVEL = "INFO"
DEFAULT_ACCESS_LOG = True
DEFAULT_EMBEDDINGS_DIR = "./embeddings"
